# DelftDashboard
Development of a more modular Python based version of the all-time great Matlab DDB equivalent

See also the journal publication of van Ormondt et al. 2020: https://doi.org/10.2166/hydro.2020.092

This will in time replace the Matlab version, which is now still functioning as GUI from Matlab, or as standalone executable:
https://publicwiki.deltares.nl/display/DDB/Delft+Dashboard 


